#
# spec file for package gnu_parallel
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnu_parallel
Version:        20151022
Release:        52.1
Summary:        Shell tool for executing jobs in parallel
License:        GPL-3.0+
Group:          Productivity/File utilities
Url:            http://www.gnu.org/software/parallel/
#DL-URL: 	http://ftp.gnu.org/gnu/parallel/
Source:         http://ftp.gnu.org/gnu/parallel/parallel-%version.tar.bz2
Source2:        http://ftp.gnu.org/gnu/parallel/parallel-%version.tar.bz2.sig
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
GNU Parallel is a shell tool for executing jobs in parallel using one
or more computers. A job can be a single command or a small script
that has to be run for each of the lines in the input. The typical
input is a list of files, a list of hosts, a list of users, a list of
URLs, or a list of tables. A job can also be a command that reads from
a pipe. GNU Parallel can then split the input and pipe it into
commands in parallel.

%package doc
Summary:        Documentation for GNU parallel
Group:          Documentation/HTML

%description doc
GNU Parallel is a shell tool for executing jobs in parallel using one
or more computers.
This subpackage contains the documentation for Parallel.

%prep
%setup -q -n parallel-%version

%build
%configure --docdir="%_docdir/%name"
make %{?_smp_mflags}

%install
%__make DESTDIR=%{buildroot} install
cp -a CITATION COPYING NEWS README "%buildroot/%_docdir/%name/"

%files
%defattr(-,root,root)
%_bindir/niceload
%_bindir/parallel
%_bindir/sem
%_bindir/sql
%_mandir/man1/*.1*
%_mandir/man7/*.7*

%files doc
%defattr(-,root,root)
%_docdir/%name/

%changelog
* Sat Oct 24 2015 mpluskal@suse.com
- Update to 20151022
  * --plus makes it possible to use {##} as a short had for {=
  $_=$Global::JobQueue->total_jobs() =} which gives the the
  number of jobs to run.
  * {= $_=$Global::JobQueue->total_jobs() =} is incompatible with
  - X, -m, and --xargs.
* Tue Sep 22 2015 mpluskal@suse.com
- Update to 20150922
  * Bug fixes and man page updates.
* Wed Sep  9 2015 mpluskal@suse.com
- Update to 20150822
  * If $job->skip() is called in {= =} the job will not be run.
  * @arg can now be used in {= =}: parallel echo '{= $arg[2] < 5
    and $_="j" =}' ::: 1 2 3 ::: 4 5 6
* Fri Jul 24 2015 astieger@suse.com
- GNU parallel 20150722:
  * If a record fits in a block, --block only reads upto the size
    of --block. If not: --block reads a full --block more.
  * Due to widely spread distributions still using --tollef even
    after a  year of being retired following a year of being
    obsolete, --tollef now gives an error unless used with --gnu.
  * --nice now uses a perl wrapper instead of the nice command.
* Sun Jul 19 2015 astieger@suse.com
- GNU parallel 20150622:
  * --halt has been rewritten completely. You can now combine
    percentages with success or fail. See the man page.
  * Exit values 102..254 have been removed. 101 means more than 100
    jobs failed.
  * Killing through --timeout, --memfree, or --halt is now done as
    a process group.
  * --termseq determines which signals are sent when a job is
    killed.
  * An empty argument would previously cause no string to be
    inserted. This is now changed to '' being inserted, thus
    prepending a space to the output of: parallel echo {} b ::: ''
  * $PARALLEL_ENV can now be set to an environment prepending the
    command. Used in env_parallel as mentioned in the manpage.
  * --retry-failed will retry all failed jobs in a joblog. It will
    ignore any command given.
  * --ssh and $PARALLEL_SSH can be used to set the command used for
    ssh. The command is assumed to behave the same way as ssh.
  * --fifo now works in csh, too.
  * Q(...) can be used in {= =} to shell quote a string.
* Sat May 23 2015 astieger@suse.com
- GNU parallel 20150522: [boo#932143]
  * Security: The security issue for --sshlogin + --fifo/--cat has
    been fixed. Thereby all issues with
    http://lists.gnu.org/archive/html/parallel/2015-04/msg00045.html
    have been fixed.
  * Security: After further security analysis the issue fixed in
    20150422 also fixed the problem for --tmux.
* Sun Apr 26 2015 astieger@suse.com
- GNU parallel 20150422:
  * Security fix: A local attacker could make a user overwrite one
    of his own files with a single byte when using --compress,
  - -tmux, --pipe, --cat or --fifo when guessing random file names
    within a time window of 15 ms. [boo#928664]
  * --shuf will generate all jobs, and shuffle them before running
    them. This is useful to get a quick preview of the results before
    running the full batch.
  * Bug fixes and man page updates.
* Sun Mar 22 2015 jengelh@inai.de
- Avoid SLE11SP3 build failure by not mixing %%doc with %%_docdir/%%name
  in the files list.
- Split documentation (82%%) into separate package per
  rpmlint suggestion
* Sun Mar 22 2015 astieger@suse.com
- GNU parallel 20150322:
  * --number-of-cores respects 'taskset' on GNU/Linux.
  * --joblog --pipe gives the data send and received in the log.
  * GNU Parallel was tested to support 100 GB sized records in
  - -pipe. A few bugs was fixed to support >2 GB records. It works,
    but is rather slow.
  * Bug fixes and man page updates.
- remove fdupes, not required
* Thu Mar  5 2015 astieger@suse.com
- GNU parallel 20150222:
  * --tmux has gotten a major overhaul.
  * Bug fixes and man page updates.
- includes changes from 20150122:
  * Remote jobs now send stderr (standard error) to stderr
    (standard error) instead of stdout (standard output).
  * Remote execution command is now packed using base64 encoded
    bzip2. This means that big environments (app. 100 KB) can be
    transferred. This change makes remote execution alpha quality.
  * --semaphoretimeout now takes a negative value. This means give
    up if the semaphore is not gotten within the timeout.
  * --halt -1 and -2 now means halt if a job succeeds (so the
    opposite of 1 and 2).
  * --no-keep-order will reverse --keep-order.
  * Bash's second fix of shellshock caused --env to break again
    when exporting functions. This has been fixed again.
  * A semibig refactoring of big functions. All non-trivial
    functions are now less than 100 lines. The refactoring makes
    this release beta quality.
  * A description of the design decisions for GNU Parallel can be
    found in 'man parallel_design'.
  * A bug fix in replacement strings caused rewrite of the
    replacement function. This makes use of replacement strings
    alpha quality.
  * Bug fixes and man page updates.
* Mon Dec  8 2014 jengelh@inai.de
- Update to new upstream release 20141122
  * Remote systems can be divided into hostgroups (e.g. web and db)
  by prepending '@groupname/' to the sshlogin. Multiple groups can
  be given by separating groups with '+'.
  E.g. @web/www1 @web+db/www2 @db/mariadb
  * Remote execution can be restricted to servers that are part of
  one or more groups by '@groupname' as an sshlogin. Multiple
  groups can be given by separating groups with '+'.
  E.g. -S @web or -S @db+web
* Wed Aug  6 2014 jengelh@inai.de
- Update to new upstream release 20140722
  * {= perl expression =} can be used as replacement string. The
  expression should modify $_. E.g. {= s/\.gz$// =} to remove .gz
  from the string. This makes replacement strings extremely flexible.
  * Positional perl expressions (similar to {2}) are given as
  {=2 perl expression=} where 2 is the position.
  * One small backwards incompatability: {1}_{2} will replace {2}
  with the empty string if there is only one argument. Previously,
  {2} would have been left untouched.
  * Replacement strings can be defined using --rpl. E.g. parallel
  - -rpl '{.gz} s/\.gz$//' echo {.gz} ::: *.gz
  * --tmux will direct the output to a tmux session instead of files.
  Each running jobs will be in its own window.
  * --halt 10%% will stop spawning new jobs if 10%% failed so far.
* Sat Jun 28 2014 jengelh@inai.de
- Update to new upstream release 20140622
  * The "--pipepart" option works with "--header", "--regexp",
  "--cat" and "--fifo".
  * "{%%}" works as job slot.
* Mon May 26 2014 jengelh@inai.de
- Update to new upstream release 20130522
  * --tollef has been retired. The format of --eta and --joblog has
  changed slightly.
  * added --pipepart, a highly efficient alternative to --pipe if the
  input is a real file and not a pipe. If using --cat or --fifo
  with --pipe, the {} in the command will be replaced with the name
  of a physical file and a fifo respectively containing the block
  from --pipe.
  * --controlmaster is no longer experimental.
  * --env is now copied when determining CPUs on remote system. It is
  useful for copying $PATH if parallel is not in the normal path.
  * --results now chops the argument if the argument is longer than
  the allowed path length.
* Sat Nov 23 2013 jengelh@inai.de
- Update to new upstream release 20131122
  * A citation notice is printed on stderr only if stderr is a
  terminal, the user has not specified --no-notice, and the user
  has not run --bibtex once.
  * --compress will compress temporary files.
  * --compress-program controls which program to use for compressing
  temporary files.
  * --bar shows progress as a progress bar compatible with zenity.
  * --resume can now be used with --result:
  jobs already run will be skipped.
  * --transfer and --basefile support paths relative to the --workdir
  by inserting /./ into the path.
* Mon Oct 28 2013 jengelh@inai.de
- Update to new upstream release 20131022
  * Using --transfer with files containing /./ in the path will copy
  the files relative to the --workdir. The maximal command length
  is now cached in a file, halving the startup time.
* Mon Sep 30 2013 jengelh@inai.de
- Update to new upstream release 20130922
  * PDF-files of documentation is now included. Bugfixes and man page
  updates have been made.
- Remove fix-pod-syntax.diff (merged upstream)
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 20130722
  * --round-robin with --pipe will now write all blocks to
  already-running jobs.
  * --env can now transfer the Bash function for remote execution.
* Sun Jun 23 2013 jengelh@inai.de
- Update to new upstream release 20130522
  * --ctrlc is now the default if --pipe is not used, making it
  possible to kill remotely-started jobs simply by pressing Ctrl-C.
  * --timeout 200%% now means "kill jobs which take more than twice
  the time of the median runtime of a job".
  * Jobs are now distributed round-robin when having mulitiple
  - -sshlogin, instead of filling up one --sshlogin at a time.
- Update to new upstream release 20130622
  * --xapply now recycles arguments if an input source has more
  arguments than others.
  * The sleep time between jobs is now both increased and decreased
  exponentially.
* Thu Jun 20 2013 coolo@suse.com
- add fix-pod-syntax.diff to fix build with perl 5.18
* Wed May  8 2013 jengelh@inai.de
- Update to new upstream release 20130422
  * --ctrlc will send SIGINT to tasks running on remote computers and
  thus killing them.
  * --load now uses `ps` to see immediately see the number of running
  processes instead of `uptime` thus making --load react much faster.
  * --retries works with --onall.
  * --nice works under tcsh.
- Ship license file and do tarball signature verification
* Wed Feb 27 2013 jengelh@inai.de
- Initial package (version 20130222) for build.opensuse.org
